@@ -209,6 +209,9 @@ class WikiBot(BaseBot):
     def get_outings(self, filters):
         return self.get_documents(constructor=objects.Outing, filters=filters)
 
+    def get_xreports(self, filters):
+        return self.get_documents(constructor=objects.Xreport, filters=filters)
+
     def get_documents(self, filters=None, document_type=None, constructor=None):
         """
         Return a list of wiki objects, this function is a generator
@@ -236,7 +239,7 @@ class WikiBot(BaseBot):
             data = self.get(url)
 
             if len(data["documents"]) == 0:
-                raise StopIteration
+                return
 
             for doc in data["documents"]:
                 yield doc
@@ -282,7 +285,7 @@ class WikiBot(BaseBot):
             for item in d["feed"]:
                 written_at = parser.parse(item["written_at"])
                 if written_at < oldest_date:
-                    raise StopIteration
+                    return
 
                 if newest_date > written_at:
                     yield objects.Contribution(self.campbot, item)
@@ -325,6 +328,9 @@ class ForumBot(BaseBot):
         return [objects.ForumUser(self.campbot, user) for user in result]
 
     def add_users_to_group(self, group_name, users):
+        for user in users:
+            assert not user.startswith("@"), "Please provide names without trailing @"
+
         group = self.get("/groups/{}.json".format(group_name))
 
         data = {"usernames": ",".join(users)}
@@ -413,13 +419,53 @@ class CampBot(object):
         self.forum.get(res["redirect_internal"].replace(self.forum.api_url, ""))
         self.forum.headers['X-CSRF-Token'] = self.forum.get("/session/csrf")["csrf"]
 
-    def check_voters(self, url, allowed_groups=None):
+    def check_voters(self, url, allowed_group="contributeurs", aggregated_report=True):
+
+        def print_aggregated_report():
+
+            sort_option = options[0]
+
+            th = "<th>{}</th>".format
+            td = "<td>{} <small>({}%)</small></td>".format
+
+            table = [[th("Vote")] + [th(option) for option in options] + [th("Total")]]
+
+            for poll_name, values in sorted(polls.items(),
+                                            key=lambda item: item[1][sort_option],
+                                            reverse=True):
+
+                total = sum(values.values())
+
+                row = [th(poll_name)]
+
+                for option in options:
+                    value = values.get(option, 0)
+                    row.append(td(value, int(100.0 * value / total)))
+
+                row.append(th(total))
+                table.append(row)
+
+            print("<table>")
+
+            for row in table:
+                print("<tr>\n  {}\n</tr>".format("\n  ".join(row)))
+
+            print("</table>\n")
+
+        def print_normal_report():
+            for poll in sorted(polls):
+                print("* " + poll)
+                for option in polls[poll]:
+                    print("  * {} : {}".format(option, polls[poll][option]))
+
+            print()
 
         allowed_members = set()
-        for group in allowed_groups or []:
-            for user in self.forum.get_group_members(group):
+        if allowed_group:
+            for user in self.forum.get_group_members(allowed_group):
                 allowed_members.add(user.username)
 
+        print("Allowed members :", allowed_members)
         ignored_voters = set()
         polls = {}
         options = []
@@ -430,7 +476,7 @@ class CampBot(object):
             polls[poll_name] = {option.html: 0 for option in post.polls[poll_name].options}
             for option in post.polls[poll_name].options:
                 for voter in option.get_voters(post.id, poll_name):
-                    if voter.username in allowed_members or allowed_groups is None:
+                    if voter.username in allowed_members or allowed_group is None:
                         polls[poll_name][option.html] += 1
                     else:
                         ignored_voters.add(voter.username)
@@ -438,37 +484,13 @@ class CampBot(object):
                 if option.html not in options:
                     options.append(option.html)
 
-        sort_option = options[0]
-
-        th = "<th>{}</th>".format
-        td = "<td>{} <small>({}%)</small></td>".format
-
-        table = [[th("Vote")] + [th(option) for option in options] + [th("Total")]]
-
-        for poll_name, values in sorted(polls.items(),
-                                        key=lambda item: item[1][sort_option],
-                                        reverse=True):
-
-            total = sum(values.values())
-
-            row = [th(poll_name)]
-
-            for option in options:
-                value = values.get(option, 0)
-                row.append(td(value, int(100.0 * value / total)))
-
-            row.append(th(total))
-            table.append(row)
-
-        print("<table>")
-
-        for row in table:
-            print("<tr>\n  {}\n</tr>".format("\n  ".join(row)))
-
-        print("</table>\n")
+        if aggregated_report:
+            print_aggregated_report()
+        else:
+            print_normal_report()
 
         if len(ignored_voters) != 0:
-            mentions = map("@{}".format, sorted(ignored_voters))
+            mentions = map("{}".format, sorted(ignored_voters))
             print("**{} ignored votes** : {}".format(len(ignored_voters), ", ".join(mentions)))
 
     def get_documents(self, url_or_filename):
@@ -498,7 +520,7 @@ class CampBot(object):
 
                 try:
                     yield self.wiki.get_wiki_object(item_id, item_type)
-                except HTTPError as e:  # pragma: no cover
+                except requests.HTTPError as e:  # pragma: no cover
                     print("{error}, item skipped".format(error=e))
 
     def _get_documents_from_url(self, url):
@@ -755,9 +777,11 @@ class CampBot(object):
                             display("O", user, contribs, outings["total"])
                             still_members.add(user.forum_username)
 
-        for user in association:
-            if user not in still_members:
-                display("A", user, 0)
+        for forum_username in association:
+            if forum_username not in still_members:
+                user = self.wiki.get_user(forum_name=forum_username)
+                if user.document_id not in excluded:
+                    display("A", user, 0)
 
         print("</table>")
 
@@ -775,6 +799,32 @@ class CampBot(object):
 
         return list(result.values())
 
+    def find_closest_documents(self, constructor, longitude, latitude, buffer, filters=None):
+        fake_object = {
+            "geometry": {
+                "geom": '{' + '"type":"Point", "coordinates": [{}, {}]'.format(longitude, latitude) + '}'
+            }
+        }
+
+        filters = filters or {}
+        filters["bbox"] = ",".join(map(str, [
+            longitude - buffer,
+            latitude - buffer,
+            longitude + buffer,
+            latitude + buffer
+        ]))
+
+        result = []
+
+        for document in self.wiki.get_documents(constructor=constructor, filters=filters):
+            result.append({
+                "document": document,
+                "distance": utils.compute_distance(fake_object, document)
+            })
+
+        result.sort(key=lambda item: item["distance"])
+
+        return result
 
 def _parse_filter(url):
     url = url.replace("https://www.camptocamp.org/", "")
@@ -789,7 +839,7 @@ def _parse_filter(url):
         document_type, filters = url, {}
 
     for key in filters:
-        if key == "bbox":
+        if key in ("bbox", "date"):
             filters[key] = filters[key].replace("%252C", "%2C")
         elif key in ("act", "rock_type"):
             filters[key] = filters[key].replace("%252C", ",")
