@@ -1,3 +1,7 @@
+#coding: utf-8
+
+from __future__ import print_function
+
 import sqlite3
 import re
 
@@ -496,11 +500,12 @@ if __name__ == "__main__":
     false_title_bold = r"(\n|^)#+[^\n]*\*"
 
     Dump().complete()
-    _search(r"(^|\n)(#+.*): *($|\n)", "fr")
 
-#    _search(r"((\n|^) {0,3}[LR]#.*)\n( {0,3}#)")
+#    _search(r"[dD][ue] (la|là|parking|sommet|col|refuge|relais) (redescendre|remonter|suivre|traverser|tourner|se diriger|prendre)", "fr")
 
-# with open("contributors.txt", "w") as f:
-#     for d in Dump().sql_file("campbot/sql/contrib_count.sql"):
-#         f.write("|".join(map(str, d)) + "\n")
-#         print(*d)
+#    _search(r"\b\d+ h( \d+)?\b", "fr")
+
+    with open("contributors.txt", "w") as f:
+        for d in Dump().sql_file("campbot/sql/contrib_count.sql"):
+             f.write("|".join(map(str, d)) + "\n")
+             print(*d)
